@@ -22,10 +22,13 @@
 # @author: see AUTHORS file
 
 """Imports for the openpyxl package."""
+import warnings
 
 try:
-    from lxml import etree
-    LXML = True
+    from lxml.etree import LXML_VERSION
+    LXML = LXML_VERSION >= (3, 2, 5, 0)
+    if LXML is False:
+        warnings.warn("The installed version of lxml is too old to be used with openpyxl")
 except ImportError:
     LXML = False
 
@@ -48,7 +51,7 @@ from openpyxl.reader.excel import load_workbook
 
 __major__ = 1  # for major interface/format changes
 __minor__ = 8  # for minor interface/format changes
-__release__ = 1  # for tweaks, bug-fixes, or development
+__release__ = 2  # for tweaks, bug-fixes, or development
 
 __version__ = '%d.%d.%d' % (__major__, __minor__, __release__)
 
