@@ -30,19 +30,18 @@ import warnings
 
 # compatibility imports
 
-from openpyxl.shared.compat import file
+from openpyxl.shared.compat import unicode, file, StringIO
 
 # package imports
 from openpyxl.shared.exc import OpenModeError, InvalidFileException
 from openpyxl.shared.ooxml import (ARC_SHARED_STRINGS, ARC_CORE, ARC_WORKBOOK,
                                    PACKAGE_WORKSHEETS, ARC_STYLE, ARC_THEME,
                                    ARC_CONTENT_TYPES)
-from openpyxl.shared.compat import unicode, file, BytesIO, StringIO
 from openpyxl.workbook import Workbook, DocumentProperties
 from openpyxl.reader.strings import read_string_table
 from openpyxl.reader.style import read_style_table
 from openpyxl.reader.workbook import (read_sheets_titles, read_named_ranges,
-        read_properties_core, read_excel_base_date, get_sheet_ids,
+        read_properties_core, read_excel_base_date,
         read_content_types)
 from openpyxl.reader.worksheet import read_worksheet
 from openpyxl.reader.comments import read_comments, get_comments_file
@@ -91,6 +90,9 @@ def load_workbook(filename, use_iterators=False, keep_vba=False, guess_types=Tru
 
     :param guess_types: guess cell content type and do not read it from the file
     :type guess_types: bool
+    
+    :param data_only: controls whether cells with formulae have either the formula (default) or the value stored the last time Excel read the sheet
+    :type data_only: bool
 
     :rtype: :class:`openpyxl.workbook.Workbook`
 
@@ -150,6 +152,9 @@ def _load_workbook(wb, archive, filename, use_iterators, keep_vba):
     if keep_vba:
         wb.vba_archive = archive
 
+    if use_iterators:
+        wb._archive = ZipFile(filename)
+
     # get workbook-level information
     try:
         wb.properties = read_properties_core(archive.read(ARC_CORE))
